==> core-components-file-upload-item-6.2.1.tgz: package/modern/components/status-control/status-control.js <==
import React, { useContext, useRef } from 'react';
import cn from 'classnames';
import { SuperEllipse } from '@alfalab/core-components/icon-view/super-ellipse';
import { RADIUS, MAX_PROGRESS_BAR_VALUE } from '../../const/progress-bar.js';
import { FileUploadItemContext } from '../../context/file-upload-item-context.js';
import { isUploadingStatus, isSuccessStatus, isErrorStatus } from '../../utils.js';
import { StatusControlIcon } from './components/status-control-icon/status-control-icon.js';
import { StatusControlProgressBar } from './components/status-control-progress-bar/status-control-progress-bar.js';

const styles = {"container":"file-upload-item__container_8c9h6","progress":"file-upload-item__progress_8c9h6","uploading":"file-upload-item__uploading_8c9h6","success":"file-upload-item__success_8c9h6","error":"file-upload-item__error_8c9h6","progressBarTransparent":"file-upload-item__progressBarTransparent_8c9h6","progressBarUploading":"file-upload-item__progressBarUploading_8c9h6","progressBarSuccess":"file-upload-item__progressBarSuccess_8c9h6","progressBarError":"file-upload-item__progressBarError_8c9h6"};
require('./status-control.css')

const StatusControl = () => {
    const { uploadStatus = 'INITIAL', progressBar, imageUrl } = useContext(FileUploadItemContext);
    const progressRef = useRef(null);
    if (progressRef.current && progressBar) {
        progressRef.current.style.maskImage = `conic-gradient(red ${(RADIUS / MAX_PROGRESS_BAR_VALUE) * progressBar}deg, transparent 0)`;
    }
    const isTransparentProgressBar = () => uploadStatus === 'INITIAL' || uploadStatus === 'UPLOADED' || uploadStatus === 'DELETED';
    return (React.createElement("div", { className: styles.container },
        React.createElement(SuperEllipse, { size: 48, ...(imageUrl && { imageUrl }) },
            React.createElement(StatusControlIcon, null)),
        React.createElement("div", { ref: progressRef, className: cn(styles.progress, {
                [styles.uploading]: isUploadingStatus(uploadStatus),
                [styles.success]: isSuccessStatus(uploadStatus),
                [styles.error]: isErrorStatus(uploadStatus),
            }) },
            React.createElement(StatusControlProgressBar, { className: cn({
                    [styles.progressBarTransparent]: isTransparentProgressBar(),
                    [styles.progressBarUploading]: uploadStatus === 'UPLOADING',
                    [styles.progressBarSuccess]: uploadStatus === 'SUCCESS',
                    [styles.progressBarError]: uploadStatus === 'ERROR',
                }) }))));
};

export { StatusControl };

==> core-components-file-upload-item-6.2.2.tgz: package/modern/components/status-control/status-control.js <==
import React, { useContext, useRef } from 'react';
import cn from 'classnames';
import { SuperEllipse } from '@alfalab/core-components/icon-view/super-ellipse';
import { RADIUS, MAX_PROGRESS_BAR_VALUE } from '../../const/progress-bar.js';
import { FileUploadItemContext } from '../../context/file-upload-item-context.js';
import { isUploadingStatus, isSuccessStatus, isErrorStatus } from '../../utils.js';
import { StatusControlIcon } from './components/status-control-icon/status-control-icon.js';
import { StatusControlProgressBar } from './components/status-control-progress-bar/status-control-progress-bar.js';

const styles = {"container":"file-upload-item__container_162h9","progress":"file-upload-item__progress_162h9","uploading":"file-upload-item__uploading_162h9","success":"file-upload-item__success_162h9","error":"file-upload-item__error_162h9","progressBarTransparent":"file-upload-item__progressBarTransparent_162h9","progressBarUploading":"file-upload-item__progressBarUploading_162h9","progressBarSuccess":"file-upload-item__progressBarSuccess_162h9","progressBarError":"file-upload-item__progressBarError_162h9"};
require('./status-control.css')

const StatusControl = () => {
    const { uploadStatus = 'INITIAL', progressBar, imageUrl } = useContext(FileUploadItemContext);
    const progressRef = useRef(null);
    if (progressRef.current && progressBar) {
        progressRef.current.style.maskImage = `conic-gradient(red ${(RADIUS / MAX_PROGRESS_BAR_VALUE) * progressBar}deg, transparent 0)`;
    }
    const isTransparentProgressBar = () => uploadStatus === 'INITIAL' || uploadStatus === 'UPLOADED' || uploadStatus === 'DELETED';
    return (React.createElement("div", { className: styles.container },
        React.createElement(SuperEllipse, { size: 48, ...(imageUrl && { imageUrl }) },
            React.createElement(StatusControlIcon, null)),
        React.createElement("div", { ref: progressRef, className: cn(styles.progress, {
                [styles.uploading]: isUploadingStatus(uploadStatus),
                [styles.success]: isSuccessStatus(uploadStatus),
                [styles.error]: isErrorStatus(uploadStatus),
            }) },
            React.createElement(StatusControlProgressBar, { className: cn({
                    [styles.progressBarTransparent]: isTransparentProgressBar(),
                    [styles.progressBarUploading]: uploadStatus === 'UPLOADING',
                    [styles.progressBarSuccess]: uploadStatus === 'SUCCESS',
                    [styles.progressBarError]: uploadStatus === 'ERROR',
                }) }))));
};

export { StatusControl };
